var http = require('http'),
    utility = require('./parser');
function getRemoteData(inputData) {
    let parameter = inputData.parameter;
    let apiURL = inputData.apiURL;
    let recordType = inputData.recordType;
    if (!parameter) {
        throw new Error('parameter value is missing');
    }
    if (!apiURL) {
        throw new Error('apiURL value is missing');
    }
    if (!recordType) {
        throw new Error('recordType value is missing');
    }
    //reject(err);
    //resolve(JSON.parse(body));
    return new Promise(function (resolve, reject) {

        http.get(apiURL, (response) => {
            const { statusCode } = response;
            const contentType = response.headers['content-type'];
            let error;
            if (statusCode !== 200) {
                error = new Error('Request Failed.\n' +
                    `Status Code: ${statusCode}`);
                throw new Error('recordType value is missing');
            }
            if (error) {
                response.resume();
                reject(err);
                throw new Error(error);
            }
            response.setEncoding('utf8');
            let rawData = '';
            response.on('data', (chunk) => { rawData += chunk; });
            response.on('end', () => {
                try {
                    var data = utility.getKeyValue(rawData, parameter);
                    if (data.parse) {
                        var responseData = (recordType && recordType == 'single') ? data.data[0] : data.data;
                        resolve(JSON.parse(JSON.stringify(responseData)));
                    }
                    else {
                        reject("Error while parsing data");
                        throw new Error("Error while parsing data");
                    }
                } catch (e) {
                    reject(e.message);
                    console.error(e.message);
                }
            });
        }).on('error', (e) => {
            throw new Error("Error while parsing data");
        });
    });

}

module.exports.getRemoteData = getRemoteData;